@@ -29,7 +29,7 @@
 #include <utils/qsqlquery_iterator.h>
 
 // Local
-#include "Debug.h"
+#include "DebugResources.h"
 #include "StatsPlugin.h"
 #include "Database.h"
 #include "Utils.h"
@@ -38,13 +38,13 @@
 class ResourceScoreCache::Queries {
 private:
     Queries()
-        : createResourceScoreCacheQuery(resourcesDatabase().createQuery())
-        , getResourceScoreCacheQuery(resourcesDatabase().createQuery())
-        , updateResourceScoreCacheQuery(resourcesDatabase().createQuery())
-        , getScoreAdditionQuery(resourcesDatabase().createQuery())
+        : createResourceScoreCacheQuery(resourcesDatabase()->createQuery())
+        , getResourceScoreCacheQuery(resourcesDatabase()->createQuery())
+        , updateResourceScoreCacheQuery(resourcesDatabase()->createQuery())
+        , getScoreAdditionQuery(resourcesDatabase()->createQuery())
     {
 
-        Utils::prepare(resourcesDatabase(),
+        Utils::prepare(*resourcesDatabase(),
             createResourceScoreCacheQuery, QStringLiteral(
             "INSERT INTO ResourceScoreCache "
             "VALUES (:usedActivity, :initiatingAgent, :targettedResource, "
@@ -53,7 +53,7 @@ private:
                     ":firstUpdate)"
         ));
 
-        Utils::prepare(resourcesDatabase(),
+        Utils::prepare(*resourcesDatabase(),
             getResourceScoreCacheQuery, QStringLiteral(
             "SELECT cachedScore, lastUpdate, firstUpdate FROM ResourceScoreCache "
             "WHERE "
@@ -62,7 +62,7 @@ private:
                 ":targettedResource = targettedResource "
         ));
 
-        Utils::prepare(resourcesDatabase(),
+        Utils::prepare(*resourcesDatabase(),
             updateResourceScoreCacheQuery, QStringLiteral(
             "UPDATE ResourceScoreCache SET "
                 "cachedScore = :cachedScore, "
@@ -73,7 +73,7 @@ private:
                 ":targettedResource = targettedResource "
         ));
 
-        Utils::prepare(resourcesDatabase(),
+        Utils::prepare(*resourcesDatabase(),
             getScoreAdditionQuery, QStringLiteral(
             "SELECT start, end "
             "FROM ResourceEvent "
@@ -153,9 +153,9 @@ void ResourceScoreCache::update()
     QDateTime currentTime = QDateTime::currentDateTime();
     qreal score = 0;
 
-    DATABASE_TRANSACTION(resourcesDatabase());
+    DATABASE_TRANSACTION(*resourcesDatabase());
 
-    qDebug() << "Creating the cache for: " << d->resource;
+    qCDebug(KAMD_LOG_RESOURCES) << "Creating the cache for: " << d->resource;
 
     // This can fail if we have the cache already made
     auto isCacheNew = Utils::exec(
@@ -180,9 +180,9 @@ void ResourceScoreCache::update()
         lastUpdate.setTime_t(result["lastUpdate"].toUInt());
         firstUpdate.setTime_t(result["firstUpdate"].toUInt());
 
-        qDebug() << "Already in database? " << (!isCacheNew);
-        qDebug() << "      First update : " << firstUpdate;
-        qDebug() << "       Last update : " << lastUpdate;
+        qCDebug(KAMD_LOG_RESOURCES) << "Already in database? " << (!isCacheNew);
+        qCDebug(KAMD_LOG_RESOURCES) << "      First update : " << firstUpdate;
+        qCDebug(KAMD_LOG_RESOURCES) << "       Last update : " << lastUpdate;
 
         if (isCacheNew) {
             // If we haven't had the cache before, set the score to 0
@@ -200,10 +200,10 @@ void ResourceScoreCache::update()
     // Calculating the updated score
     // We are processing all events since the last cache update
 
-    qDebug() << "After the adjustment";
-    qDebug() << "     Current score : " << score;
-    qDebug() << "      First update : " << firstUpdate;
-    qDebug() << "       Last update : " << lastUpdate;
+    qCDebug(KAMD_LOG_RESOURCES) << "After the adjustment";
+    qCDebug(KAMD_LOG_RESOURCES) << "     Current score : " << score;
+    qCDebug(KAMD_LOG_RESOURCES) << "      First update : " << firstUpdate;
+    qCDebug(KAMD_LOG_RESOURCES) << "       Last update : " << lastUpdate;
 
     Utils::exec(Utils::FailOnError, Queries::self().getScoreAdditionQuery,
         ":usedActivity", d->activity,
@@ -220,7 +220,7 @@ void ResourceScoreCache::update()
         const auto end = result["end"].toUInt();
         const auto intervalLength = end - lastEventStart;
 
-        qDebug() << "Interval length is " << intervalLength;
+        qCDebug(KAMD_LOG_RESOURCES) << "Interval length is " << intervalLength;
 
         if (intervalLength == 0) {
             // We have an Accessed event - otherwise, this wouldn't be 0
@@ -232,7 +232,7 @@ void ResourceScoreCache::update()
         }
     }
 
-    qDebug() << "         New score : " << score;
+    qCDebug(KAMD_LOG_RESOURCES) << "         New score : " << score;
 
     // Updating the score
 
@@ -245,10 +245,10 @@ void ResourceScoreCache::update()
     );
 
     // Notifying the world
-    qDebug() << "ResourceScoreUpdated:"
-             << d->activity
-             << d->application
-             << d->resource
+    qCDebug(KAMD_LOG_RESOURCES) << "ResourceScoreUpdated:"
+                                << d->activity
+                                << d->application
+                                << d->resource
         ;
     emit QMetaObject::invokeMethod(StatsPlugin::self(),
                                    "ResourceScoreUpdated",
