@@ -24,6 +24,8 @@
 #include <common/database/schema/ResourcesDatabaseSchema.h>
 #include <memory>
 
+#include "DebugResources.h"
+
 namespace Utils {
 
     static unsigned int errorCount = 0;
@@ -61,8 +63,8 @@ namespace Utils {
 
         if (eh == FailOnError) {
             if ((!success) && (errorCount++ < 2)) {
-                qDebug() << query.lastQuery();
-                qDebug() << query.lastError();
+                qCDebug(KAMD_LOG_RESOURCES) << query.lastQuery();
+                qCDebug(KAMD_LOG_RESOURCES) << query.lastError();
             }
             Q_ASSERT_X(success, "Uils::exec", "Query failed");
         }
